==> snipe-it-7.0.13.zip: snipe-it-7.0.13/resources/lang/es-MX/localizations.php <==
<?php

return [

    'select_language' => 'Seleccione un idioma',
    'languages' => [
        'en-US'=> 'Inglés, EEUU',
        'en-GB'=> 'Inglés, Reino Unido',
        'am-ET' => 'Amharic',
        'af-ZA'=> 'Afrikaans',
        'ar-SA'=> 'Árabe',
        'bg-BG'=> 'Búlgaro',
        'zh-CN'=> 'Chino simplificado',
        'zh-TW'=> 'Chino tradicional',
        'ca-ES' => 'Catalán',
        'hr-HR'=> 'Croata',
        'cs-CZ'=> 'Checo',
        'da-DK'=> 'Danés',
        'nl-NL'=> 'Holandés',
        'en-ID'=> 'Inglés, Indonesia',
        'et-EE'=> 'Estonio',
        'fil-PH'=> 'Filipino',
        'fi-FI'=> 'Finlandés',
        'fr-FR'=> 'Francés',
        'de-DE'=> 'Alemán',
        'de-if'=> 'Alemán (informal)',
        'el-GR'=> 'Griego',
        'he-IL'=> 'Hebreo',
        'hu-HU'=> 'Húngaro',
        'is-IS' => 'Icelandic',
        'id-ID'=> 'Indonesio/a',
        'ga-IE'=> 'Irlandés',
        'it-IT'=> 'Italiano',
        'ja-JP'=> 'Japonés',
        'km-KH'=>'Khmer',
        'ko-KR'=> 'Coreano',
        'lt-LT'=>'Lituano',
        'lv-LV'=> 'Letón',
        'mk-MK'=> 'Macedonio',
        'ms-MY'=> 'Malayo',
        'mi-NZ'=> 'Maori',
        'mn-MN'=> 'Mongol',
        //'no-NO'=> 'Norwegian',
        'nb-NO'=> 'Noruego Bokmål',
        //'nn-NO'=> 'Norwegian Nynorsk',
        'fa-IR'=> 'Persa',
        'pl-PL'=> 'Polaco',
        'pt-PT'=> 'Portugués',
        'pt-BR'=> 'Portugués, Brasileño',
        'ro-RO'=> 'Rumano',
        'ru-RU'=> 'Ruso',
        'sr-CS' => 'Serbian (Latin)',
        'sk-SK'=> 'Eslovaco',
        'sl-SI'=> 'Esloveno',
        'so-SO'=> 'Somali',
        'es-ES'=> 'Español',
        'es-CO'=> 'Español, Colombia',
        'es-MX'=> 'Español, México',
        'es-VE'=> 'Español, Venezuela',
        'sv-SE'=> 'Sueco',
        'tl-PH'=> 'Tagalog',
        'ta-IN'=> 'Tamil',
        'th-TH'=> 'Tailandés',
        'tr-TR'=> 'Turco',
        'uk-UA'=> 'Ucraniano',
        'vi-VN'=> 'Vietnamita',
        'cy-GB'=> 'Galés',
        'zu-ZA'=> 'Zulú',
    ],

    'select_country' => 'Seleccione un país',
    
    'countries' => [
        'AC'=>'Isla de Ascensión',
        'AD'=>'Andorra',
        'AE'=>'Emiratos Árabes Unidos',
        'AF'=>'Afganistán',
        'AG'=>'Antigua y Barbuda',
        'AI'=>'Anguilla',
        'AL'=>'Albania',
        'AM'=>'Armenia',
        'AN'=>'Antillas Holandesas',
        'AO'=>'Angola',
        'AQ'=>'La antártida',
        'AR'=>'Argentina',
        'AS'=>'Samoa Estadounidense',
        'AT'=>'Austria',
        'AU'=>'Australia',
        'AW'=>'Aruba',
        'AX'=>'Islas Åland',
        'AZ'=>'Azerbaiyán',
        'BA'=>'Bosnia y Herzegovina',
        'BB'=>'Barbados',
        'BE'=>'Bélgica',
        'BD'=>'Bangladesh',
        'BF'=>'Burkina Faso',
        'BG'=>'Bulgaria',
        'BH'=>'Baréin',
        'BI'=>'Burundi',
        'BJ'=>'Benin',
        'BM'=>'Bermuda',
        'BN'=>'Brunéi Darussalam',
        'BO'=>'Bolivia',
        'BR'=>'Brasil',
        'BS'=>'Bahamas',
        'BT'=>'Bhutan',
        'BV'=>'La Isla De Bouvet',
        'BW'=>'Botswana',
        'BY'=>'Bielorrusia',
        'BZ'=>'Belice',
        'CA'=>'Canadá',
        'CC'=>'Islas Cocos (Keeling)',
        'CD'=>'Congo (República Democrática)',
        'CF'=>'República Centroafricana',
        'CG'=>'Congo (República)',
        'CH'=>'Suiza',
        'CI'=>'Costa de Marfil',
        'CK'=>'Islas Cook',
        'CL'=>'Chile',
        'CM'=>'Camerún',
        'CN'=>'República Popular China',
        'CO'=>'Colombia',
        'CR'=>'Costa Rica',
        'CU'=>'Cuba',
        'CV'=>'Cabo Verde',
        'CX'=>'Isla de Navidad',
        'CY'=>'Chipre',
        'CZ'=>'República Checa',
        'DE'=>'Alemania',
        'DJ'=>'Djibuti',
        'DK'=>'Dinamarca',
        'DM'=>'Domínica',
        'DO'=>'República Dominicana',
        'DZ'=>'Argelia',
        'EC'=>'Ecuador',
        'EE'=>'Estonia',
        'EG'=>'Egipto',
        'GB-ENG'=>'Inglaterra',
        'ER'=>'Eritrea',
        'ES'=>'España',
        'ET'=>'Etiopía',
        'EU'=>'Unión Europea',
        'FI'=>'Finlandia',
        'FJ'=>'Fiji',
        'FK'=>'Islas Falkland (Malvinas)',
        'FM'=>'Estados Federados de la Micronesia',
        'FO'=>'Islas Faroe',
        'FR'=>'Francia',
        'GA'=>'Gabon',
        'GD'=>'Granada',
        'GE'=>'Georgia',
        'GF'=>'Guayana Francesa',
        'GG'=>'Guernsey',
        'GH'=>'Ghana',
        'GI'=>'Gibraltar',
        'GL'=>'Groenlandia',
        'GM'=>'Gambia',
        'GN'=>'Guinea',
        'GP'=>'Guadalupe',
        'GQ'=>'Guinea Ecuatorial',
        'GR'=>'Grecia',
        'GS'=>'Georgia del sur y las Islas Sandwich del Sur',
        'GT'=>'Guatemala',
        'GU'=>'Guam',
        'GW'=>'Guinea-Bisáu',
        'GY'=>'Guyana',
        'HK'=>'Hong Kong',
        'HM'=>'Islas Heard y Mc Donald',
        'HN'=>'Honduras',
        'HR'=>'Croacia (nombre local: Hrvatska)',
        'HT'=>'Haití',
        'HU'=>'Hungría',
        'ID'=>'Indonesia',
        'IE'=>'Irlanda',
        'IL'=>'Israel',
        'IM'=>'Isla de Man',
        'IN'=>'India',
        'IO'=>'Territorio Británico del Océano Índico',
        'IQ'=>'Irak',
        'IR'=>'Irán, República Islámica Del',
        'IS'=>'Islandia',
        'IT'=>'Italia',
        'JE'=>'Jersey',
        'JM'=>'Jamaica',
        'JO'=>'Jordania',
        'JP'=>'Japón',
        'KE'=>'Kenia',
        'KG'=>'Kyrgyzstan',
        'KH'=>'Camboya',
        'KI'=>'Kiribati',
        'KM'=>'Comoras',
        'KN'=>'San Cristóbal y Nevis',
        'KR'=>'Corea del Sur',
        'KW'=>'Kuwait',
        'KY'=>'Islas Caimán',
        'KZ'=>'Kazakan',
        'LA'=>'República Democrática Popular Laos',
        'LB'=>'Líbano',
        'LC'=>'Santa Lucía',
        'LI'=>'Liechtenstein',
        'LK'=>'Sri Lanka',
        'LR'=>'Liberia',
        'LS'=>'Lesotho',
        'LT'=>'Lithuania',
        'LU'=>'Luxemburgo',
        'LV'=>'Letonia',
        'LY'=>'Jamahiriya Árabe Libia',
        'MA'=>'Marruecos',
        'MC'=>'Mónaco',
        'MD'=>'Repúplica de Moldavia',
        'ME'=>'Montenegro',
        'MG'=>'Madagascar',
        'MH'=>'Islas Marshall',
        'MK'=>'Macedonia, Ex República Yugoslava de',
        'ML'=>'Mali',
        'MM'=>'Myanmar',
        'MN'=>'Mongolia',
        'MO'=>'Macao',
        'MP'=>'Islas Mariana del Norte',
        'MQ'=>'Martinica',
        'MR'=>'Mauritania',
        'MS'=>'Montserrat',
        'MT'=>'Malta',
        'MU'=>'Mauricio',
        'MV'=>'Maldivas',
        'MW'=>'Malawi',
        'MX'=>'México',
        'MY'=>'Malasia',
        'MZ'=>'Mozambique',
        'NA'=>'Namibia',
        'NC'=>'Nueva Caledonia',
        'NE'=>'Niger',
        'NF'=>'Isla Norfolk',
        'NG'=>'Nigeria',
        'NI'=>'Nicaragua',
        'NL'=>'Países Bajos',
        'GB-NIR' => 'Irlanda del Norte',
        'NO'=>'Noruega',
        'NP'=>'Nepal',
        'NR'=>'Nauru',
        'NU'=>'Isla Niue',
        'NZ'=>'Nueva Zelanda',
        'OM'=>'Omán',
        'PA'=>'Panamá',
        'PE'=>'Perú',
        'PF'=>'Polinesia Francesa',
        'PG'=>'Papúa Nueva Guinea',
        'PH'=>'Republica de Filipinas',
        'PK'=>'Pakistán',
        'PL'=>'Polonia',
        'PM'=>'San Pedro y Miquelón',
        'PN'=>'Islas Pitcairn',
        'PR'=>'Puerto Rico',
        'PS'=>'Palestine',
        'PT'=>'Portugal',
        'PW'=>'Palau',
        'PY'=>'Paraguay',
        'QA'=>'Qatar',
        'RE'=>'Reunión',
        'RO'=>'Rumania',
        'RS'=>'Serbia',
        'RU'=>'Federación Rusa',
        'RW'=>'Ruanda',
        'SA'=>'Arabia Saudita',
        'GB-SCT'=>'Escocia',
        'SB'=>'Islas Salomón',
        'SC'=>'Seychelles',
        'SS'=>'Sudán del Sur',
        'SD'=>'Sudán',
        'SE'=>'Suecia',
        'SG'=>'Singapur',
        'SH'=>'St. Helena',
        'SI'=>'Eslovenia',
        'SJ'=>'Islas Svalbard y Jan Mayen',
        'SK'=>'Eslovaquia (República Eslovaca)',
        'SL'=>'Sierra Leona',
        'SM'=>'San Marino',
        'SN'=>'Senegal',
        'SO'=>'Somalia',
        'SR'=>'Surinam',
        'ST'=>'Sao Tomé y Príncipe',
        'SU'=>'Unión Soviética',
        'SV'=>'El Salvador',
        'SY'=>'República Árabe Siria',
        'SZ'=>'Swaziland',
        'TC'=>'Islas Turcas y Caicos',
        'TD'=>'Chad',
        'TF'=>'Territorios franceses del sur',
        'TG'=>'Togo',
        'TH'=>'Tailandia',
        'TJ'=>'Tayikistán',
        'TK'=>'Tokelau',
        'TI'=>'Timor Oriental',
        'TM'=>'Turkmenistán',
        'TN'=>'Túnez',
        'TO'=>'Tonga',
        'TP'=>'Timor Oriental (código antiguo)',
        'TR'=>'Turquía',
        'TT'=>'Trinidad y Tobago',
        'TV'=>'Tuvalu',
        'TW'=>'Taiwán',
        'TZ'=>'Tanzania, República Unida de',
        'UA'=>'Ucrania',
        'UG'=>'Uganda',
        'UK'=>'Reino Unido',
        'US'=>'Estados Unidos',
        'UM'=>'Islas Menores de Estados Unidos',
        'UY'=>'Uruguay',
        'UZ'=>'Uzbekistan',
        'VA'=>'Estado del Vaticano (Santa Sede)',
        'VC'=>'San Vicente y las Granadinas',
        'VE'=>'Venezuela',
        'VG'=>'Islas Vírgenes Británicas',
        'VI'=>'Islas Vírgenes de los Estados Unidos',
        'VN'=>'Viet Nam',
        'VU'=>'Vanuatu',
        'GB-WLS' =>'Gales',
        'WF'=>'Islas Wallis y Futuna',
        'WS'=>'Samoa',
        'YE'=>'Yemen',
        'YT'=>'Mayotte',
        'ZA'=>'Sudáfrica',
        'ZM'=>'Zambia',
        'ZW'=>'Zimbabwe',
    ],
];

==> snipe-it-7.1.17.zip: snipe-it-7.1.17/resources/lang/es-MX/localizations.php <==
<?php

return [

    'select_language' => 'Seleccione un idioma',
    'languages' => [
        'en-US'=> 'Inglés, EEUU',
        'en-GB'=> 'Inglés, Reino Unido',
        'am-ET' => 'Amharic',
        'af-ZA'=> 'Afrikaans',
        'ar-SA'=> 'Árabe',
        'bg-BG'=> 'Búlgaro',
        'zh-CN'=> 'Chino simplificado',
        'zh-TW'=> 'Chino tradicional',
        'ca-ES' => 'Catalán',
        'hr-HR'=> 'Croata',
        'cs-CZ'=> 'Checo',
        'da-DK'=> 'Danés',
        'nl-NL'=> 'Holandés',
        'en-ID'=> 'Inglés, Indonesia',
        'et-EE'=> 'Estonio',
        'fil-PH'=> 'Filipino',
        'fi-FI'=> 'Finlandés',
        'fr-FR'=> 'Francés',
        'de-DE'=> 'Alemán',
        'de-if'=> 'Alemán (informal)',
        'el-GR'=> 'Griego',
        'he-IL'=> 'Hebreo',
        'hu-HU'=> 'Húngaro',
        'is-IS' => 'Icelandic',
        'id-ID'=> 'Indonesio/a',
        'ga-IE'=> 'Irlandés',
        'it-IT'=> 'Italiano',
        'ja-JP'=> 'Japonés',
        'km-KH'=>'Khmer',
        'ko-KR'=> 'Coreano',
        'lt-LT'=>'Lituano',
        'lv-LV'=> 'Letón',
        'mk-MK'=> 'Macedonio',
        'ms-MY'=> 'Malayo',
        'mi-NZ'=> 'Maori',
        'mn-MN'=> 'Mongol',
        //'no-NO'=> 'Norwegian',
        'nb-NO'=> 'Noruego Bokmål',
        //'nn-NO'=> 'Norwegian Nynorsk',
        'fa-IR'=> 'Persa',
        'pl-PL'=> 'Polaco',
        'pt-PT'=> 'Portugués',
        'pt-BR'=> 'Portugués, Brasil',
        'ro-RO'=> 'Rumano',
        'ru-RU'=> 'Ruso',
        'sr-CS' => 'Serbio (Latino)',
        'sk-SK'=> 'Eslovaco',
        'sl-SI'=> 'Esloveno',
        'so-SO'=> 'Somalí',
        'es-ES'=> 'Español',
        'es-CO'=> 'Español, Colombia',
        'es-MX'=> 'Español, México',
        'es-VE'=> 'Español, Venezuela',
        'sv-SE'=> 'Sueco',
        'tl-PH'=> 'Tagalog',
        'ta-IN'=> 'Tamil',
        'th-TH'=> 'Tailandés',
        'tr-TR'=> 'Turco',
        'uk-UA'=> 'Ucraniano',
        'vi-VN'=> 'Vietnamita',
        'cy-GB'=> 'Galés',
        'zu-ZA'=> 'Zulú',
    ],

    'select_country' => 'Seleccione un país',
    
    'countries' => [
        'AC'=>'Isla de Ascensión',
        'AD'=>'Andorra',
        'AE'=>'Emiratos Árabes Unidos',
        'AF'=>'Afganistán',
        'AG'=>'Antigua y Barbuda',
        'AI'=>'Anguilla',
        'AL'=>'Albania',
        'AM'=>'Armenia',
        'AN'=>'Antillas Holandesas',
        'AO'=>'Angola',
        'AQ'=>'La antártida',
        'AR'=>'Argentina',
        'AS'=>'Samoa Estadounidense',
        'AT'=>'Austria',
        'AU'=>'Australia',
        'AW'=>'Aruba',
        'AX'=>'Islas Aland',
        'AZ'=>'Azerbaiyán',
        'BA'=>'Bosnia y Herzegovina',
        'BB'=>'Barbados',
        'BE'=>'Bélgica',
        'BD'=>'Bangladesh',
        'BF'=>'Burkina Faso',
        'BG'=>'Bulgaria',
        'BH'=>'Baréin',
        'BI'=>'Burundi',
        'BJ'=>'Benin',
        'BM'=>'Bermuda',
        'BN'=>'Brunéi Darussalam',
        'BO'=>'Bolivia',
        'BR'=>'Brasil',
        'BS'=>'Bahamas',
        'BT'=>'Bhutan',
        'BV'=>'La Isla De Bouvet',
        'BW'=>'Botswana',
        'BY'=>'Bielorrusia',
        'BZ'=>'Belice',
        'CA'=>'Canadá',
        'CC'=>'Islas Cocos (Keeling)',
        'CD'=>'Congo (República Democrática)',
        'CF'=>'República Centroafricana',
        'CG'=>'Congo (República)',
        'CH'=>'Suiza',
        'CI'=>'Costa de Marfil',
        'CK'=>'Islas Cook',
        'CL'=>'Chile',
        'CM'=>'Camerún',
        'CN'=>'República Popular China',
        'CO'=>'Colombia',
        'CR'=>'Costa Rica',
        'CU'=>'Cuba',
        'CV'=>'Cabo Verde',
        'CX'=>'Isla de Navidad',
        'CY'=>'Chipre',
        'CZ'=>'República Checa',
        'DE'=>'Alemania',
        'DJ'=>'Djibuti',
        'DK'=>'Dinamarca',
        'DM'=>'Domínica',
        'DO'=>'República Dominicana',
        'DZ'=>'Argelia',
        'EC'=>'Ecuador',
        'EE'=>'Estonia',
        'EG'=>'Egipto',
        'GB-ENG'=>'Inglaterra',
        'ER'=>'Eritrea',
        'ES'=>'España',
        'ET'=>'Etiopía',
        'EU'=>'Unión Europea',
        'FI'=>'Finlandia',
        'FJ'=>'Fiji',
        'FK'=>'Islas Falkland (Malvinas)',
        'FM'=>'Estados Federados de la Micronesia',
        'FO'=>'Islas Faroe',
        'FR'=>'Francia',
        'GA'=>'Gabon',
        'GD'=>'Granada',
        'GE'=>'Georgia',
        'GF'=>'Guayana Francesa',
        'GG'=>'Guernsey',
        'GH'=>'Ghana',
        'GI'=>'Gibraltar',
        'GL'=>'Groenlandia',
        'GM'=>'Gambia',
        'GN'=>'Guinea',
        'GP'=>'Guadalupe',
        'GQ'=>'Guinea Ecuatorial',
        'GR'=>'Grecia',
        'GS'=>'Georgia del sur y las Islas Sandwich del Sur',
        'GT'=>'Guatemala',
        'GU'=>'Guam',
        'GW'=>'Guinea-Bisáu',
        'GY'=>'Guyana',
        'HK'=>'Hong Kong',
        'HM'=>'Islas Heard y Mc Donald',
        'HN'=>'Honduras',
        'HR'=>'Croacia (nombre local: Hrvatska)',
        'HT'=>'Haití',
        'HU'=>'Hungría',
        'ID'=>'Indonesia',
        'IE'=>'Irlanda',
        'IL'=>'Israel',
        'IM'=>'Isla de Man',
        'IN'=>'India',
        'IO'=>'Territorio Británico del Océano Índico',
        'IQ'=>'Irak',
        'IR'=>'Irán, República Islámica Del',
        'IS'=>'Islandia',
        'IT'=>'Italia',
        'JE'=>'Jersey',
        'JM'=>'Jamaica',
        'JO'=>'Jordania',
        'JP'=>'Japón',
        'KE'=>'Kenia',
        'KG'=>'Kyrgyzstan',
        'KH'=>'Camboya',
        'KI'=>'Kiribati',
        'KM'=>'Comoras',
        'KN'=>'San Cristóbal y Nevis',
        'KR'=>'Corea del Sur',
        'KW'=>'Kuwait',
        'KY'=>'Islas Caimán',
        'KZ'=>'Kazakan',
        'LA'=>'República Democrática Popular Laos',
        'LB'=>'Líbano',
        'LC'=>'Santa Lucía',
        'LI'=>'Liechtenstein',
        'LK'=>'Sri Lanka',
        'LR'=>'Liberia',
        'LS'=>'Lesotho',
        'LT'=>'Lithuania',
        'LU'=>'Luxemburgo',
        'LV'=>'Letonia',
        'LY'=>'Jamahiriya Árabe Libia',
        'MA'=>'Marruecos',
        'MC'=>'Mónaco',
        'MD'=>'Repúplica de Moldavia',
        'ME'=>'Montenegro',
        'MG'=>'Madagascar',
        'MH'=>'Islas Marshall',
        'MK'=>'Macedonia, Ex República Yugoslava de',
        'ML'=>'Mali',
        'MM'=>'Myanmar',
        'MN'=>'Mongolia',
        'MO'=>'Macao',
        'MP'=>'Islas Mariana del Norte',
        'MQ'=>'Martinica',
        'MR'=>'Mauritania',
        'MS'=>'Montserrat',
        'MT'=>'Malta',
        'MU'=>'Mauricio',
        'MV'=>'Maldivas',
        'MW'=>'Malawi',
        'MX'=>'México',
        'MY'=>'Malasia',
        'MZ'=>'Mozambique',
        'NA'=>'Namibia',
        'NC'=>'Nueva Caledonia',
        'NE'=>'Niger',
        'NF'=>'Isla Norfolk',
        'NG'=>'Nigeria',
        'NI'=>'Nicaragua',
        'NL'=>'Países Bajos',
        'GB-NIR' => 'Irlanda del Norte',
        'NO'=>'Noruega',
        'NP'=>'Nepal',
        'NR'=>'Nauru',
        'NU'=>'Isla Niue',
        'NZ'=>'Nueva Zelanda',
        'OM'=>'Omán',
        'PA'=>'Panamá',
        'PE'=>'Perú',
        'PF'=>'Polinesia Francesa',
        'PG'=>'Papúa Nueva Guinea',
        'PH'=>'Republica de Filipinas',
        'PK'=>'Pakistán',
        'PL'=>'Polonia',
        'PM'=>'San Pedro y Miquelón',
        'PN'=>'Islas Pitcairn',
        'PR'=>'Puerto Rico',
        'PS'=>'Palestine',
        'PT'=>'Portugal',
        'PW'=>'Palau',
        'PY'=>'Paraguay',
        'QA'=>'Qatar',
        'RE'=>'Reunión',
        'RO'=>'Rumania',
        'RS'=>'Serbia',
        'RU'=>'Federación Rusa',
        'RW'=>'Ruanda',
        'SA'=>'Arabia Saudita',
        'GB-SCT'=>'Escocia',
        'SB'=>'Islas Salomón',
        'SC'=>'Seychelles',
        'SS'=>'Sudán del Sur',
        'SD'=>'Sudán',
        'SE'=>'Suecia',
        'SG'=>'Singapur',
        'SH'=>'St. Helena',
        'SI'=>'Eslovenia',
        'SJ'=>'Islas Svalbard y Jan Mayen',
        'SK'=>'Eslovaquia (República Eslovaca)',
        'SL'=>'Sierra Leona',
        'SM'=>'San Marino',
        'SN'=>'Senegal',
        'SO'=>'Somalia',
        'SR'=>'Surinam',
        'ST'=>'Sao Tomé y Príncipe',
        'SU'=>'Unión Soviética',
        'SV'=>'El Salvador',
        'SY'=>'República Árabe Siria',
        'SZ'=>'Swaziland',
        'TC'=>'Islas Turcas y Caicos',
        'TD'=>'Chad',
        'TF'=>'Territorios franceses del sur',
        'TG'=>'Togo',
        'TH'=>'Tailandia',
        'TJ'=>'Tayikistán',
        'TK'=>'Tokelau',
        'TI'=>'Timor Oriental',
        'TM'=>'Turkmenistán',
        'TN'=>'Túnez',
        'TO'=>'Tonga',
        'TP'=>'Timor Oriental (código antiguo)',
        'TR'=>'Turquía',
        'TT'=>'Trinidad y Tobago',
        'TV'=>'Tuvalu',
        'TW'=>'Taiwán',
        'TZ'=>'Tanzania, República Unida de',
        'UA'=>'Ucrania',
        'UG'=>'Uganda',
        'UK'=>'Reino Unido',
        'US'=>'Estados Unidos',
        'UM'=>'Islas Menores de Estados Unidos',
        'UY'=>'Uruguay',
        'UZ'=>'Uzbekistan',
        'VA'=>'Estado del Vaticano (Santa Sede)',
        'VC'=>'San Vicente y las Granadinas',
        'VE'=>'Venezuela',
        'VG'=>'Islas Vírgenes Británicas',
        'VI'=>'Islas Vírgenes de los Estados Unidos',
        'VN'=>'Viet Nam',
        'VU'=>'Vanuatu',
        'GB-WLS' =>'Gales',
        'WF'=>'Islas Wallis y Futuna',
        'WS'=>'Samoa',
        'YE'=>'Yemen',
        'YT'=>'Mayotte',
        'ZA'=>'Sudáfrica',
        'ZM'=>'Zambia',
        'ZW'=>'Zimbabwe',
    ],
];
